PricesModel class
Constructors
Properties
-
advantagesListage
→ List<
String> -
final
- advantagesMaxLines → int
-
final
- decoration → BoxDecoration?
-
final
- emphasisText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- monthlyPrice → double
-
final
-
onTap
→ Future<
void> Function(bool isYearly) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subTitle → String
-
final
- title → String
-
final
- yearlyPrice → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited